@@ -1,7 +1,7 @@
 use v5.14;
 package RosettaCode;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 use utf8;
 use MediaWiki::Bot;
@@ -87,7 +87,11 @@ sub execute {
 sub parse_lang_page {
     my ($self, $info, $content) = @_;
     Log "Parse Language '$info->{name}'";
-    $self->write_file("Lang/$info->{path}/0DESCRIPTION", $content);
+    $self->write_symlink(
+        "Lang/$info->{path}/00SOURCE",
+        "http://rosettacode.org/wiki/Category:$info->{url}",
+    );
+    $self->write_file("Lang/$info->{path}/00DESCRIPTION", $content);
 }
 
 sub parse_task_page {
@@ -110,9 +114,7 @@ sub parse_task_page {
         $ext = ".$ext" if $ext;
         my $source = "Lang/$lang_path/$path";
         my $target = "../../Task/$path/$lang_path";
-        Log "Symlink $source -> $target";
-        unlink($source);
-        io->link($source)->assert->symlink($target);
+        $self->write_symlink($source, $target);
         if (@sections == 1) {
             $self->write_file("Task/$path/$lang_path/$file$ext", $sections[0]);
             next;
@@ -125,8 +127,12 @@ sub parse_task_page {
         }
     }
 
-    $self->write_file("Task/$path/0DESCRIPTION", $text);
-    $self->dump_file("Task/$path/1META.yaml", $meta) if $meta;
+    $self->write_symlink(
+        "Task/$path/00SOURCE",
+        "http://rosettacode.org/wiki/$info->{url}",
+    );
+    $self->write_file("Task/$path/00DESCRIPTION", $text);
+    $self->dump_file("Task/$path/00META.yaml", $meta) if $meta;
 }
 
 sub parse_description {
@@ -302,6 +308,13 @@ sub write_file {
     io->file($file)->assert->utf8->print($content);
 }
 
+sub write_symlink {
+    my ($self, $source, $target) = @_;
+    Log "Symlink $source -> $target";
+    unlink($source);
+    io->link($source)->assert->symlink($target);
+}
+
 sub dump_file {
     my ($self, $file, $object) = @_;
     Log "Dump YAML '$file'";
